@@ -1,11 +1,18 @@
-
+import gzip
+import io
+import warnings
 from collections import OrderedDict
 from functools import partial
 from importlib import import_module
-from logging import warning, warn
 from sys import version_info, version
 
 
+class JsonTricksDeprecation(UserWarning):
+	""" Special deprecation warning because the built-in one is ignored by default """
+	def __init__(self, msg):
+		super(JsonTricksDeprecation, self).__init__(msg)
+
+
 class hashodict(OrderedDict):
 	"""
 	This dictionary is hashable. It should NOT be mutated, or all kinds of weird
@@ -26,7 +33,7 @@ except ImportError:
 			if type(callable) == partial and version_info[0] == 2:
 				if not hasattr(get_arg_names, '__warned_partial_argspec'):
 					get_arg_names.__warned_partial_argspec = True
-					warn("'functools.partial' and 'inspect.getargspec' are not compatible in this Python version; "
+					warnings.warn("'functools.partial' and 'inspect.getargspec' are not compatible in this Python version; "
 						"ignoring the 'partial' wrapper when inspecting arguments of {}, which can lead to problems".format(callable))
 				return set(getargspec(callable.func).args)
 			argspec = getargspec(callable)
@@ -42,15 +49,6 @@ else:
 		return set(sig.parameters.keys())
 
 
-def call_with_optional_kwargs(callable, *args, **optional_kwargs):
-	accepted_kwargs = get_arg_names(callable)
-	use_kwargs = {}
-	for key, val in optional_kwargs.items():
-		if key in accepted_kwargs:
-			use_kwargs[key] = val
-	return callable(*args, **use_kwargs)
-
-
 class NoNumpyException(Exception):
 	""" Trying to use numpy features, but numpy cannot be found. """
 
@@ -63,6 +61,10 @@ class NoEnumException(Exception):
 	""" Trying to use enum features, but enum cannot be found. """
 
 
+class NoPathlibException(Exception):
+	""" Trying to use pathlib features, but pathlib cannot be found. """
+
+
 class ClassInstanceHookBase(object):
 	def __init__(self, cls_lookup_map=None):
 		self.cls_lookup_map = cls_lookup_map or {}
@@ -155,7 +157,7 @@ def get_module_name_from_object(obj):
 	mod = obj.__class__.__module__
 	if mod == '__main__':
 		mod = None
-		warning(('class {0:} seems to have been defined in the main file; unfortunately this means'
+		warnings.warn(('class {0:} seems to have been defined in the main file; unfortunately this means'
 			' that it\'s module/import path is unknown, so you might have to provide cls_lookup_map when '
 			'decoding').format(obj.__class__))
 	return mod
@@ -167,6 +169,29 @@ def nested_index(collection, indices):
 	return collection
 
 
+def dict_default(dictionary, key, default_value):
+	if key not in dictionary:
+		dictionary[key] = default_value
+
+
+def gzip_compress(data, compresslevel):
+	"""
+	Do gzip compression, without the timestamp. Similar to gzip.compress, but without timestamp, and also before py3.2.
+	"""
+	buf = io.BytesIO()
+	with gzip.GzipFile(fileobj=buf, mode='wb', compresslevel=compresslevel, mtime=0) as fh:
+		fh.write(data)
+	return buf.getvalue()
+
+
+def gzip_decompress(data):
+	"""
+	Do gzip decompression, without the timestamp. Just like gzip.decompress, but that's py3.2+.
+	"""
+	with gzip.GzipFile(fileobj=io.BytesIO(data)) as f:
+		return f.read()
+
+
 is_py3 = (version[:2] == '3.')
 str_type = str if is_py3 else (basestring, unicode,)
 
